import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.ApplicationFilter("example", {});
 * ```
 */
export declare class ApplicationFilter extends pulumi.CustomResource {
    /**
     * Get an existing ApplicationFilter resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ApplicationFilterState, opts?: pulumi.CustomResourceOptions): ApplicationFilter;
    /**
     * Returns true if the given object is an instance of ApplicationFilter.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ApplicationFilter;
    /**
     * The Categories param. Individual elements in this list are subject to additional validation. String length must not exceed 128 characters.
     */
    readonly categories: pulumi.Output<string[] | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * only True is a valid value.
     */
    readonly evasive: pulumi.Output<boolean | undefined>;
    /**
     * only True is a valid value.
     */
    readonly excessiveBandwidthUse: pulumi.Output<boolean | undefined>;
    /**
     * The Excludes param. Individual elements in this list are subject to additional validation. String length must not exceed 63 characters.
     */
    readonly excludes: pulumi.Output<string[] | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * only True is a valid value.
     */
    readonly hasKnownVulnerabilities: pulumi.Output<boolean | undefined>;
    /**
     * only True is a valid value.
     */
    readonly isSaas: pulumi.Output<boolean | undefined>;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    readonly name: pulumi.Output<string>;
    /**
     * only True is a valid value.
     */
    readonly newAppid: pulumi.Output<boolean | undefined>;
    /**
     * only True is a valid value.
     */
    readonly pervasive: pulumi.Output<boolean | undefined>;
    /**
     * only True is a valid value.
     */
    readonly proneToMisuse: pulumi.Output<boolean | undefined>;
    /**
     * The Risks param. Individual elements in this list are subject to additional validation. Value must be between 1 and 5.
     */
    readonly risks: pulumi.Output<number[] | undefined>;
    /**
     * The SaasCertifications param. Individual elements in this list are subject to additional validation. String length must not exceed 32 characters.
     */
    readonly saasCertifications: pulumi.Output<string[] | undefined>;
    /**
     * The SaasRisks param. Individual elements in this list are subject to additional validation. String length must not exceed 32 characters.
     */
    readonly saasRisks: pulumi.Output<string[] | undefined>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    /**
     * The Subcategories param. Individual elements in this list are subject to additional validation. String length must not exceed 128 characters.
     */
    readonly subcategories: pulumi.Output<string[] | undefined>;
    /**
     * The Tagging param.
     */
    readonly tagging: pulumi.Output<outputs.ApplicationFilterTagging | undefined>;
    /**
     * The Technologies param. Individual elements in this list are subject to additional validation. String length must not exceed 128 characters.
     */
    readonly technologies: pulumi.Output<string[] | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * only True is a valid value.
     */
    readonly transfersFiles: pulumi.Output<boolean | undefined>;
    /**
     * only True is a valid value.
     */
    readonly tunnelsOtherApps: pulumi.Output<boolean | undefined>;
    /**
     * only True is a valid value.
     */
    readonly usedByMalware: pulumi.Output<boolean | undefined>;
    /**
     * Create a ApplicationFilter resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ApplicationFilterArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ApplicationFilter resources.
 */
export interface ApplicationFilterState {
    /**
     * The Categories param. Individual elements in this list are subject to additional validation. String length must not exceed 128 characters.
     */
    categories?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * only True is a valid value.
     */
    evasive?: pulumi.Input<boolean>;
    /**
     * only True is a valid value.
     */
    excessiveBandwidthUse?: pulumi.Input<boolean>;
    /**
     * The Excludes param. Individual elements in this list are subject to additional validation. String length must not exceed 63 characters.
     */
    excludes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * only True is a valid value.
     */
    hasKnownVulnerabilities?: pulumi.Input<boolean>;
    /**
     * only True is a valid value.
     */
    isSaas?: pulumi.Input<boolean>;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * only True is a valid value.
     */
    newAppid?: pulumi.Input<boolean>;
    /**
     * only True is a valid value.
     */
    pervasive?: pulumi.Input<boolean>;
    /**
     * only True is a valid value.
     */
    proneToMisuse?: pulumi.Input<boolean>;
    /**
     * The Risks param. Individual elements in this list are subject to additional validation. Value must be between 1 and 5.
     */
    risks?: pulumi.Input<pulumi.Input<number>[]>;
    /**
     * The SaasCertifications param. Individual elements in this list are subject to additional validation. String length must not exceed 32 characters.
     */
    saasCertifications?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The SaasRisks param. Individual elements in this list are subject to additional validation. String length must not exceed 32 characters.
     */
    saasRisks?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The Subcategories param. Individual elements in this list are subject to additional validation. String length must not exceed 128 characters.
     */
    subcategories?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Tagging param.
     */
    tagging?: pulumi.Input<inputs.ApplicationFilterTagging>;
    /**
     * The Technologies param. Individual elements in this list are subject to additional validation. String length must not exceed 128 characters.
     */
    technologies?: pulumi.Input<pulumi.Input<string>[]>;
    tfid?: pulumi.Input<string>;
    /**
     * only True is a valid value.
     */
    transfersFiles?: pulumi.Input<boolean>;
    /**
     * only True is a valid value.
     */
    tunnelsOtherApps?: pulumi.Input<boolean>;
    /**
     * only True is a valid value.
     */
    usedByMalware?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a ApplicationFilter resource.
 */
export interface ApplicationFilterArgs {
    /**
     * The Categories param. Individual elements in this list are subject to additional validation. String length must not exceed 128 characters.
     */
    categories?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * only True is a valid value.
     */
    evasive?: pulumi.Input<boolean>;
    /**
     * only True is a valid value.
     */
    excessiveBandwidthUse?: pulumi.Input<boolean>;
    /**
     * The Excludes param. Individual elements in this list are subject to additional validation. String length must not exceed 63 characters.
     */
    excludes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * only True is a valid value.
     */
    hasKnownVulnerabilities?: pulumi.Input<boolean>;
    /**
     * only True is a valid value.
     */
    isSaas?: pulumi.Input<boolean>;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * only True is a valid value.
     */
    newAppid?: pulumi.Input<boolean>;
    /**
     * only True is a valid value.
     */
    pervasive?: pulumi.Input<boolean>;
    /**
     * only True is a valid value.
     */
    proneToMisuse?: pulumi.Input<boolean>;
    /**
     * The Risks param. Individual elements in this list are subject to additional validation. Value must be between 1 and 5.
     */
    risks?: pulumi.Input<pulumi.Input<number>[]>;
    /**
     * The SaasCertifications param. Individual elements in this list are subject to additional validation. String length must not exceed 32 characters.
     */
    saasCertifications?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The SaasRisks param. Individual elements in this list are subject to additional validation. String length must not exceed 32 characters.
     */
    saasRisks?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The Subcategories param. Individual elements in this list are subject to additional validation. String length must not exceed 128 characters.
     */
    subcategories?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Tagging param.
     */
    tagging?: pulumi.Input<inputs.ApplicationFilterTagging>;
    /**
     * The Technologies param. Individual elements in this list are subject to additional validation. String length must not exceed 128 characters.
     */
    technologies?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * only True is a valid value.
     */
    transfersFiles?: pulumi.Input<boolean>;
    /**
     * only True is a valid value.
     */
    tunnelsOtherApps?: pulumi.Input<boolean>;
    /**
     * only True is a valid value.
     */
    usedByMalware?: pulumi.Input<boolean>;
}
