import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.AuthenticationProfile("example", {});
 * ```
 */
export declare class AuthenticationProfile extends pulumi.CustomResource {
    /**
     * Get an existing AuthenticationProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AuthenticationProfileState, opts?: pulumi.CustomResourceOptions): AuthenticationProfile;
    /**
     * Returns true if the given object is an instance of AuthenticationProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AuthenticationProfile;
    /**
     * The AllowList param.
     */
    readonly allowLists: pulumi.Output<string[] | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The Lockout param.
     */
    readonly lockout: pulumi.Output<outputs.AuthenticationProfileLockout | undefined>;
    /**
     * The Method param.
     */
    readonly method: pulumi.Output<outputs.AuthenticationProfileMethod | undefined>;
    /**
     * The MultiFactorAuth param.
     */
    readonly multiFactorAuth: pulumi.Output<outputs.AuthenticationProfileMultiFactorAuth | undefined>;
    /**
     * The Name param.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The SingleSignOn param.
     */
    readonly singleSignOn: pulumi.Output<outputs.AuthenticationProfileSingleSignOn | undefined>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The UserDomain param. String length must not exceed 63 characters.
     */
    readonly userDomain: pulumi.Output<string | undefined>;
    /**
     * The UsernameModifier param. String must be one of these: `"%USERINPUT%"`, `"%USERINPUT%@%USERDOMAIN%"`, `"%USERDOMAIN%\\%USERINPUT%"`.
     */
    readonly usernameModifier: pulumi.Output<string | undefined>;
    /**
     * Create a AuthenticationProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: AuthenticationProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AuthenticationProfile resources.
 */
export interface AuthenticationProfileState {
    /**
     * The AllowList param.
     */
    allowLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Lockout param.
     */
    lockout?: pulumi.Input<inputs.AuthenticationProfileLockout>;
    /**
     * The Method param.
     */
    method?: pulumi.Input<inputs.AuthenticationProfileMethod>;
    /**
     * The MultiFactorAuth param.
     */
    multiFactorAuth?: pulumi.Input<inputs.AuthenticationProfileMultiFactorAuth>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The SingleSignOn param.
     */
    singleSignOn?: pulumi.Input<inputs.AuthenticationProfileSingleSignOn>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
    /**
     * The UserDomain param. String length must not exceed 63 characters.
     */
    userDomain?: pulumi.Input<string>;
    /**
     * The UsernameModifier param. String must be one of these: `"%USERINPUT%"`, `"%USERINPUT%@%USERDOMAIN%"`, `"%USERDOMAIN%\\%USERINPUT%"`.
     */
    usernameModifier?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a AuthenticationProfile resource.
 */
export interface AuthenticationProfileArgs {
    /**
     * The AllowList param.
     */
    allowLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Lockout param.
     */
    lockout?: pulumi.Input<inputs.AuthenticationProfileLockout>;
    /**
     * The Method param.
     */
    method?: pulumi.Input<inputs.AuthenticationProfileMethod>;
    /**
     * The MultiFactorAuth param.
     */
    multiFactorAuth?: pulumi.Input<inputs.AuthenticationProfileMultiFactorAuth>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The SingleSignOn param.
     */
    singleSignOn?: pulumi.Input<inputs.AuthenticationProfileSingleSignOn>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The UserDomain param. String length must not exceed 63 characters.
     */
    userDomain?: pulumi.Input<string>;
    /**
     * The UsernameModifier param. String must be one of these: `"%USERINPUT%"`, `"%USERINPUT%@%USERDOMAIN%"`, `"%USERDOMAIN%\\%USERINPUT%"`.
     */
    usernameModifier?: pulumi.Input<string>;
}
