import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.AuthenticationRule("example", {});
 * ```
 */
export declare class AuthenticationRule extends pulumi.CustomResource {
    /**
     * Get an existing AuthenticationRule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AuthenticationRuleState, opts?: pulumi.CustomResourceOptions): AuthenticationRule;
    /**
     * Returns true if the given object is an instance of AuthenticationRule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AuthenticationRule;
    /**
     * the authentication profile name to apply to authentication rule.
     */
    readonly authenticationEnforcement: pulumi.Output<string | undefined>;
    /**
     * The Categories param.
     */
    readonly categories: pulumi.Output<string[] | undefined>;
    /**
     * The Description param.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The DestinationHips param.
     */
    readonly destinationHips: pulumi.Output<string[] | undefined>;
    /**
     * The Destinations param.
     */
    readonly destinations: pulumi.Output<string[] | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Disabled param. Default: `false`.
     */
    readonly disabled: pulumi.Output<boolean>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The Froms param.
     */
    readonly froms: pulumi.Output<string[] | undefined>;
    /**
     * The GroupTag param.
     */
    readonly groupTag: pulumi.Output<string | undefined>;
    /**
     * The HipProfiles param.
     */
    readonly hipProfiles: pulumi.Output<string[] | undefined>;
    /**
     * The LogAuthenticationTimeout param. Default: `false`.
     */
    readonly logAuthenticationTimeout: pulumi.Output<boolean>;
    /**
     * The LogSetting param.
     */
    readonly logSetting: pulumi.Output<string | undefined>;
    /**
     * The Name param.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The NegateDestination param. Default: `false`.
     */
    readonly negateDestination: pulumi.Output<boolean>;
    /**
     * The NegateSource param. Default: `false`.
     */
    readonly negateSource: pulumi.Output<boolean>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    readonly position: pulumi.Output<string>;
    /**
     * The Services param.
     */
    readonly services: pulumi.Output<string[] | undefined>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    /**
     * The SourceHips param.
     */
    readonly sourceHips: pulumi.Output<string[] | undefined>;
    /**
     * The SourceUsers param.
     */
    readonly sourceUsers: pulumi.Output<string[] | undefined>;
    /**
     * The Sources param.
     */
    readonly sources: pulumi.Output<string[] | undefined>;
    /**
     * The Tags param.
     */
    readonly tags: pulumi.Output<string[] | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The Timeout param. Value must be between 1 and 1440.
     */
    readonly timeout: pulumi.Output<number | undefined>;
    /**
     * The Tos param.
     */
    readonly tos: pulumi.Output<string[] | undefined>;
    /**
     * Create a AuthenticationRule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: AuthenticationRuleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AuthenticationRule resources.
 */
export interface AuthenticationRuleState {
    /**
     * the authentication profile name to apply to authentication rule.
     */
    authenticationEnforcement?: pulumi.Input<string>;
    /**
     * The Categories param.
     */
    categories?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The DestinationHips param.
     */
    destinationHips?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Destinations param.
     */
    destinations?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Disabled param. Default: `false`.
     */
    disabled?: pulumi.Input<boolean>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Froms param.
     */
    froms?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The GroupTag param.
     */
    groupTag?: pulumi.Input<string>;
    /**
     * The HipProfiles param.
     */
    hipProfiles?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The LogAuthenticationTimeout param. Default: `false`.
     */
    logAuthenticationTimeout?: pulumi.Input<boolean>;
    /**
     * The LogSetting param.
     */
    logSetting?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The NegateDestination param. Default: `false`.
     */
    negateDestination?: pulumi.Input<boolean>;
    /**
     * The NegateSource param. Default: `false`.
     */
    negateSource?: pulumi.Input<boolean>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    position?: pulumi.Input<string>;
    /**
     * The Services param.
     */
    services?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The SourceHips param.
     */
    sourceHips?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The SourceUsers param.
     */
    sourceUsers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Sources param.
     */
    sources?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Tags param.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    tfid?: pulumi.Input<string>;
    /**
     * The Timeout param. Value must be between 1 and 1440.
     */
    timeout?: pulumi.Input<number>;
    /**
     * The Tos param.
     */
    tos?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a AuthenticationRule resource.
 */
export interface AuthenticationRuleArgs {
    /**
     * the authentication profile name to apply to authentication rule.
     */
    authenticationEnforcement?: pulumi.Input<string>;
    /**
     * The Categories param.
     */
    categories?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The DestinationHips param.
     */
    destinationHips?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Destinations param.
     */
    destinations?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Disabled param. Default: `false`.
     */
    disabled?: pulumi.Input<boolean>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Froms param.
     */
    froms?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The GroupTag param.
     */
    groupTag?: pulumi.Input<string>;
    /**
     * The HipProfiles param.
     */
    hipProfiles?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The LogAuthenticationTimeout param. Default: `false`.
     */
    logAuthenticationTimeout?: pulumi.Input<boolean>;
    /**
     * The LogSetting param.
     */
    logSetting?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The NegateDestination param. Default: `false`.
     */
    negateDestination?: pulumi.Input<boolean>;
    /**
     * The NegateSource param. Default: `false`.
     */
    negateSource?: pulumi.Input<boolean>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    position?: pulumi.Input<string>;
    /**
     * The Services param.
     */
    services?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The SourceHips param.
     */
    sourceHips?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The SourceUsers param.
     */
    sourceUsers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Sources param.
     */
    sources?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Tags param.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Timeout param. Value must be between 1 and 1440.
     */
    timeout?: pulumi.Input<number>;
    /**
     * The Tos param.
     */
    tos?: pulumi.Input<pulumi.Input<string>[]>;
}
