import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.DnsSecurityProfile("example", {});
 * ```
 */
export declare class DnsSecurityProfile extends pulumi.CustomResource {
    /**
     * Get an existing DnsSecurityProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DnsSecurityProfileState, opts?: pulumi.CustomResourceOptions): DnsSecurityProfile;
    /**
     * Returns true if the given object is an instance of DnsSecurityProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DnsSecurityProfile;
    /**
     * The BotnetDomains param.
     */
    readonly botnetDomains: pulumi.Output<outputs.DnsSecurityProfileBotnetDomains | undefined>;
    /**
     * The Description param.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The Name param.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * Create a DnsSecurityProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: DnsSecurityProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering DnsSecurityProfile resources.
 */
export interface DnsSecurityProfileState {
    /**
     * The BotnetDomains param.
     */
    botnetDomains?: pulumi.Input<inputs.DnsSecurityProfileBotnetDomains>;
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a DnsSecurityProfile resource.
 */
export interface DnsSecurityProfileArgs {
    /**
     * The BotnetDomains param.
     */
    botnetDomains?: pulumi.Input<inputs.DnsSecurityProfileBotnetDomains>;
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
}
