import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getAppOverrideRule({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getAppOverrideRule(args: GetAppOverrideRuleArgs, opts?: pulumi.InvokeOptions): Promise<GetAppOverrideRuleResult>;
/**
 * A collection of arguments for invoking getAppOverrideRule.
 */
export interface GetAppOverrideRuleArgs {
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getAppOverrideRule.
 */
export interface GetAppOverrideRuleResult {
    /**
     * The Application param.
     */
    readonly application: string;
    /**
     * The Description param. String length must not exceed 1024 characters.
     */
    readonly description: string;
    /**
     * The Destinations param.
     */
    readonly destinations: string[];
    /**
     * The Disabled param. Default: `false`.
     */
    readonly disabled: boolean;
    /**
     * The Froms param.
     */
    readonly froms: string[];
    /**
     * The GroupTag param.
     */
    readonly groupTag: string;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * The Name param. String length must not exceed 63 characters. String validation regex: `^[a-zA-Z0-9._-]+$`.
     */
    readonly name: string;
    /**
     * The NegateDestination param. Default: `false`.
     */
    readonly negateDestination: boolean;
    /**
     * The NegateSource param. Default: `false`.
     */
    readonly negateSource: boolean;
    /**
     * The Port param. Value must be between 0 and 65535.
     */
    readonly port: number;
    /**
     * The Protocol param. String must be one of these: `"tcp"`, `"udp"`.
     */
    readonly protocol: string;
    /**
     * The Sources param.
     */
    readonly sources: string[];
    /**
     * The Tags param.
     */
    readonly tags: string[];
    readonly tfid: string;
    /**
     * The Tos param.
     */
    readonly tos: string[];
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getAppOverrideRule({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getAppOverrideRuleOutput(args: GetAppOverrideRuleOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAppOverrideRuleResult>;
/**
 * A collection of arguments for invoking getAppOverrideRule.
 */
export interface GetAppOverrideRuleOutputArgs {
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
