import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a listing of config items.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getRemoteNetworkList({
 *     folder: "Remote Networks",
 * });
 * ```
 */
export declare function getRemoteNetworkList(args?: GetRemoteNetworkListArgs, opts?: pulumi.InvokeOptions): Promise<GetRemoteNetworkListResult>;
/**
 * A collection of arguments for invoking getRemoteNetworkList.
 */
export interface GetRemoteNetworkListArgs {
    /**
     * The Folder param. String can either be a specific string(`"Remote Networks"`) or match this regex: `^[\s0-9a-zA-Z._-]{1,}$`. Default: `"Remote Networks"`.
     */
    folder?: string;
    /**
     * The Limit param. A limit of -1 will return all configured items. Default: `200`.
     */
    limit?: number;
    /**
     * The Name param.
     */
    name?: string;
    /**
     * The Offset param. Default: `0`.
     */
    offset?: number;
}
/**
 * A collection of values returned by getRemoteNetworkList.
 */
export interface GetRemoteNetworkListResult {
    /**
     * The Data param.
     */
    readonly datas: outputs.GetRemoteNetworkListData[];
    /**
     * The Folder param. String can either be a specific string(`"Remote Networks"`) or match this regex: `^[\s0-9a-zA-Z._-]{1,}$`. Default: `"Remote Networks"`.
     */
    readonly folder: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The Limit param. A limit of -1 will return all configured items. Default: `200`.
     */
    readonly limit: number;
    /**
     * The Name param.
     */
    readonly name?: string;
    /**
     * The Offset param. Default: `0`.
     */
    readonly offset: number;
    readonly tfid: string;
    /**
     * The Total param.
     */
    readonly total: number;
}
/**
 * Retrieves a listing of config items.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getRemoteNetworkList({
 *     folder: "Remote Networks",
 * });
 * ```
 */
export declare function getRemoteNetworkListOutput(args?: GetRemoteNetworkListOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRemoteNetworkListResult>;
/**
 * A collection of arguments for invoking getRemoteNetworkList.
 */
export interface GetRemoteNetworkListOutputArgs {
    /**
     * The Folder param. String can either be a specific string(`"Remote Networks"`) or match this regex: `^[\s0-9a-zA-Z._-]{1,}$`. Default: `"Remote Networks"`.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Limit param. A limit of -1 will return all configured items. Default: `200`.
     */
    limit?: pulumi.Input<number>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Offset param. Default: `0`.
     */
    offset?: pulumi.Input<number>;
}
