import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getScepProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getScepProfile(args: GetScepProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetScepProfileResult>;
/**
 * A collection of arguments for invoking getScepProfile.
 */
export interface GetScepProfileArgs {
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getScepProfile.
 */
export interface GetScepProfileResult {
    /**
     * The Algorithm param.
     */
    readonly algorithm: outputs.GetScepProfileAlgorithm;
    /**
     * The CaIdentityName param.
     */
    readonly caIdentityName: string;
    /**
     * The CertificateAttributes param.
     */
    readonly certificateAttributes: outputs.GetScepProfileCertificateAttributes;
    /**
     * The Digest param.
     */
    readonly digest: string;
    /**
     * The Fingerprint param.
     */
    readonly fingerprint: string;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    readonly name: string;
    /**
     * The ScepCaCert param.
     */
    readonly scepCaCert: string;
    /**
     * The ScepChallenge param.
     */
    readonly scepChallenge: outputs.GetScepProfileScepChallenge;
    /**
     * The ScepClientCert param.
     */
    readonly scepClientCert: string;
    /**
     * The ScepUrl param.
     */
    readonly scepUrl: string;
    /**
     * The Subject param.
     */
    readonly subject: string;
    readonly tfid: string;
    /**
     * The UseAsDigitalSignature param.
     */
    readonly useAsDigitalSignature: boolean;
    /**
     * The UseForKeyEncipherment param.
     */
    readonly useForKeyEncipherment: boolean;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getScepProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getScepProfileOutput(args: GetScepProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetScepProfileResult>;
/**
 * A collection of arguments for invoking getScepProfile.
 */
export interface GetScepProfileOutputArgs {
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
