import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getServiceConnection({
 *     id: "1234-56-789",
 *     folder: "Service Connections",
 * });
 * ```
 */
export declare function getServiceConnection(args: GetServiceConnectionArgs, opts?: pulumi.InvokeOptions): Promise<GetServiceConnectionResult>;
/**
 * A collection of arguments for invoking getServiceConnection.
 */
export interface GetServiceConnectionArgs {
    /**
     * The Folder param. String can either be a specific string(`"Service Connections"`) or match this regex: `^[0-9a-zA-Z._\s-]{1,}$`. Default: `"Service Connections"`.
     */
    folder?: string;
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getServiceConnection.
 */
export interface GetServiceConnectionResult {
    /**
     * The BackupSC param.
     */
    readonly backupSC: string;
    /**
     * The BgpPeer param.
     */
    readonly bgpPeer: outputs.GetServiceConnectionBgpPeer;
    /**
     * The Folder param. String can either be a specific string(`"Service Connections"`) or match this regex: `^[0-9a-zA-Z._\s-]{1,}$`. Default: `"Service Connections"`.
     */
    readonly folder: string;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * The IpsecTunnel param.
     */
    readonly ipsecTunnel: string;
    /**
     * The Name param.
     */
    readonly name: string;
    /**
     * The NatPool param.
     */
    readonly natPool: string;
    /**
     * The NoExportCommunity param. String must be one of these: `"Disabled"`, `"Enabled-In"`, `"Enabled-Out"`, `"Enabled-Both"`.
     */
    readonly noExportCommunity: string;
    /**
     * The OnboardingType param. String must be one of these: `"classic"`. Default: `"classic"`.
     */
    readonly onboardingType: string;
    /**
     * The Protocol param.
     */
    readonly protocol: outputs.GetServiceConnectionProtocol;
    /**
     * The Qos param.
     */
    readonly qos: outputs.GetServiceConnectionQos;
    /**
     * The Region param.
     */
    readonly region: string;
    /**
     * The SecondaryIpsecTunnel param.
     */
    readonly secondaryIpsecTunnel: string;
    /**
     * The SourceNat param.
     */
    readonly sourceNat: boolean;
    /**
     * The Subnets param.
     */
    readonly subnets: string[];
    readonly tfid: string;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getServiceConnection({
 *     id: "1234-56-789",
 *     folder: "Service Connections",
 * });
 * ```
 */
export declare function getServiceConnectionOutput(args: GetServiceConnectionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetServiceConnectionResult>;
/**
 * A collection of arguments for invoking getServiceConnection.
 */
export interface GetServiceConnectionOutputArgs {
    /**
     * The Folder param. String can either be a specific string(`"Service Connections"`) or match this regex: `^[0-9a-zA-Z._\s-]{1,}$`. Default: `"Service Connections"`.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
