import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a listing of config items.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getTrafficSteeringRuleList({
 *     folder: "Service Connections",
 * });
 * ```
 */
export declare function getTrafficSteeringRuleList(args?: GetTrafficSteeringRuleListArgs, opts?: pulumi.InvokeOptions): Promise<GetTrafficSteeringRuleListResult>;
/**
 * A collection of arguments for invoking getTrafficSteeringRuleList.
 */
export interface GetTrafficSteeringRuleListArgs {
    /**
     * The Folder param. String can either be a specific string(`"Service Connections"`) or match this regex: `^[0-9a-zA-Z._\s-]{1,}$`. Default: `"Service Connections"`.
     */
    folder?: string;
    /**
     * The Limit param. A limit of -1 will return all configured items. Default: `200`.
     */
    limit?: number;
    /**
     * The Name param.
     */
    name?: string;
    /**
     * The Offset param. Default: `0`.
     */
    offset?: number;
}
/**
 * A collection of values returned by getTrafficSteeringRuleList.
 */
export interface GetTrafficSteeringRuleListResult {
    /**
     * The Data param.
     */
    readonly datas: outputs.GetTrafficSteeringRuleListData[];
    /**
     * The Folder param. String can either be a specific string(`"Service Connections"`) or match this regex: `^[0-9a-zA-Z._\s-]{1,}$`. Default: `"Service Connections"`.
     */
    readonly folder: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The Limit param. A limit of -1 will return all configured items. Default: `200`.
     */
    readonly limit: number;
    /**
     * The Name param.
     */
    readonly name?: string;
    /**
     * The Offset param. Default: `0`.
     */
    readonly offset: number;
    readonly tfid: string;
    /**
     * The Total param.
     */
    readonly total: number;
}
/**
 * Retrieves a listing of config items.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getTrafficSteeringRuleList({
 *     folder: "Service Connections",
 * });
 * ```
 */
export declare function getTrafficSteeringRuleListOutput(args?: GetTrafficSteeringRuleListOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetTrafficSteeringRuleListResult>;
/**
 * A collection of arguments for invoking getTrafficSteeringRuleList.
 */
export interface GetTrafficSteeringRuleListOutputArgs {
    /**
     * The Folder param. String can either be a specific string(`"Service Connections"`) or match this regex: `^[0-9a-zA-Z._\s-]{1,}$`. Default: `"Service Connections"`.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Limit param. A limit of -1 will return all configured items. Default: `200`.
     */
    limit?: pulumi.Input<number>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The Offset param. Default: `0`.
     */
    offset?: pulumi.Input<number>;
}
