import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.IpsecTunnel("example", {});
 * ```
 */
export declare class IpsecTunnel extends pulumi.CustomResource {
    /**
     * Get an existing IpsecTunnel resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: IpsecTunnelState, opts?: pulumi.CustomResourceOptions): IpsecTunnel;
    /**
     * Returns true if the given object is an instance of IpsecTunnel.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IpsecTunnel;
    /**
     * Enable Anti-Replay check on this tunnel.
     */
    readonly antiReplay: pulumi.Output<boolean | undefined>;
    /**
     * The AutoKey param.
     */
    readonly autoKey: pulumi.Output<outputs.IpsecTunnelAutoKey>;
    /**
     * Copy IP TOS bits from inner packet to IPSec packet (not recommended). Default: `false`.
     */
    readonly copyTos: pulumi.Output<boolean>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * allow GRE over IPSec. Default: `false`.
     */
    readonly enableGreEncapsulation: pulumi.Output<boolean>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * Alphanumeric string begin with letter: [0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The TunnelMonitor param.
     */
    readonly tunnelMonitor: pulumi.Output<outputs.IpsecTunnelTunnelMonitor | undefined>;
    /**
     * Create a IpsecTunnel resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IpsecTunnelArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering IpsecTunnel resources.
 */
export interface IpsecTunnelState {
    /**
     * Enable Anti-Replay check on this tunnel.
     */
    antiReplay?: pulumi.Input<boolean>;
    /**
     * The AutoKey param.
     */
    autoKey?: pulumi.Input<inputs.IpsecTunnelAutoKey>;
    /**
     * Copy IP TOS bits from inner packet to IPSec packet (not recommended). Default: `false`.
     */
    copyTos?: pulumi.Input<boolean>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * allow GRE over IPSec. Default: `false`.
     */
    enableGreEncapsulation?: pulumi.Input<boolean>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * Alphanumeric string begin with letter: [0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
    /**
     * The TunnelMonitor param.
     */
    tunnelMonitor?: pulumi.Input<inputs.IpsecTunnelTunnelMonitor>;
}
/**
 * The set of arguments for constructing a IpsecTunnel resource.
 */
export interface IpsecTunnelArgs {
    /**
     * Enable Anti-Replay check on this tunnel.
     */
    antiReplay?: pulumi.Input<boolean>;
    /**
     * The AutoKey param.
     */
    autoKey: pulumi.Input<inputs.IpsecTunnelAutoKey>;
    /**
     * Copy IP TOS bits from inner packet to IPSec packet (not recommended). Default: `false`.
     */
    copyTos?: pulumi.Input<boolean>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * allow GRE over IPSec. Default: `false`.
     */
    enableGreEncapsulation?: pulumi.Input<boolean>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * Alphanumeric string begin with letter: [0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The TunnelMonitor param.
     */
    tunnelMonitor?: pulumi.Input<inputs.IpsecTunnelTunnelMonitor>;
}
