import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.QosProfile("example", {});
 * ```
 */
export declare class QosProfile extends pulumi.CustomResource {
    /**
     * Get an existing QosProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: QosProfileState, opts?: pulumi.CustomResourceOptions): QosProfile;
    /**
     * Returns true if the given object is an instance of QosProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is QosProfile;
    /**
     * The AggregateBandwidth param.
     */
    readonly aggregateBandwidth: pulumi.Output<outputs.QosProfileAggregateBandwidth | undefined>;
    /**
     * The ClassBandwidthType param.
     */
    readonly classBandwidthType: pulumi.Output<outputs.QosProfileClassBandwidthType | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * Alphanumeric string begin with letter: [0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * Create a QosProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: QosProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering QosProfile resources.
 */
export interface QosProfileState {
    /**
     * The AggregateBandwidth param.
     */
    aggregateBandwidth?: pulumi.Input<inputs.QosProfileAggregateBandwidth>;
    /**
     * The ClassBandwidthType param.
     */
    classBandwidthType?: pulumi.Input<inputs.QosProfileClassBandwidthType>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * Alphanumeric string begin with letter: [0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a QosProfile resource.
 */
export interface QosProfileArgs {
    /**
     * The AggregateBandwidth param.
     */
    aggregateBandwidth?: pulumi.Input<inputs.QosProfileAggregateBandwidth>;
    /**
     * The ClassBandwidthType param.
     */
    classBandwidthType?: pulumi.Input<inputs.QosProfileClassBandwidthType>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * Alphanumeric string begin with letter: [0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
}
