import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.SamlServerProfile("example", {});
 * ```
 */
export declare class SamlServerProfile extends pulumi.CustomResource {
    /**
     * Get an existing SamlServerProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SamlServerProfileState, opts?: pulumi.CustomResourceOptions): SamlServerProfile;
    /**
     * Returns true if the given object is an instance of SamlServerProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SamlServerProfile;
    /**
     * The Certificate param. String length must not exceed 63 characters.
     */
    readonly certificate: pulumi.Output<string>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The EntityId param. String length must be between 1 and 1024 characters.
     */
    readonly entityId: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The MaxClockSkew param. Value must be between 1 and 900.
     */
    readonly maxClockSkew: pulumi.Output<number | undefined>;
    /**
     * The SloBindings param. String must be one of these: `"post"`, `"redirect"`.
     */
    readonly sloBindings: pulumi.Output<string | undefined>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    /**
     * The SsoBindings param. String must be one of these: `"post"`, `"redirect"`.
     */
    readonly ssoBindings: pulumi.Output<string | undefined>;
    /**
     * The SsoUrl param. String length must be between 1 and 255 characters.
     */
    readonly ssoUrl: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The ValidateIdpCertificate param.
     */
    readonly validateIdpCertificate: pulumi.Output<boolean | undefined>;
    /**
     * The WantAuthRequestsSigned param.
     */
    readonly wantAuthRequestsSigned: pulumi.Output<boolean | undefined>;
    /**
     * Create a SamlServerProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SamlServerProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SamlServerProfile resources.
 */
export interface SamlServerProfileState {
    /**
     * The Certificate param. String length must not exceed 63 characters.
     */
    certificate?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The EntityId param. String length must be between 1 and 1024 characters.
     */
    entityId?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The MaxClockSkew param. Value must be between 1 and 900.
     */
    maxClockSkew?: pulumi.Input<number>;
    /**
     * The SloBindings param. String must be one of these: `"post"`, `"redirect"`.
     */
    sloBindings?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The SsoBindings param. String must be one of these: `"post"`, `"redirect"`.
     */
    ssoBindings?: pulumi.Input<string>;
    /**
     * The SsoUrl param. String length must be between 1 and 255 characters.
     */
    ssoUrl?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
    /**
     * The ValidateIdpCertificate param.
     */
    validateIdpCertificate?: pulumi.Input<boolean>;
    /**
     * The WantAuthRequestsSigned param.
     */
    wantAuthRequestsSigned?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a SamlServerProfile resource.
 */
export interface SamlServerProfileArgs {
    /**
     * The Certificate param. String length must not exceed 63 characters.
     */
    certificate: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The EntityId param. String length must be between 1 and 1024 characters.
     */
    entityId?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The MaxClockSkew param. Value must be between 1 and 900.
     */
    maxClockSkew?: pulumi.Input<number>;
    /**
     * The SloBindings param. String must be one of these: `"post"`, `"redirect"`.
     */
    sloBindings?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The SsoBindings param. String must be one of these: `"post"`, `"redirect"`.
     */
    ssoBindings?: pulumi.Input<string>;
    /**
     * The SsoUrl param. String length must be between 1 and 255 characters.
     */
    ssoUrl?: pulumi.Input<string>;
    /**
     * The ValidateIdpCertificate param.
     */
    validateIdpCertificate?: pulumi.Input<boolean>;
    /**
     * The WantAuthRequestsSigned param.
     */
    wantAuthRequestsSigned?: pulumi.Input<boolean>;
}
