import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.ServiceConnectionGroup("example", {});
 * ```
 */
export declare class ServiceConnectionGroup extends pulumi.CustomResource {
    /**
     * Get an existing ServiceConnectionGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ServiceConnectionGroupState, opts?: pulumi.CustomResourceOptions): ServiceConnectionGroup;
    /**
     * Returns true if the given object is an instance of ServiceConnectionGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ServiceConnectionGroup;
    /**
     * The DisableSnat param.
     */
    readonly disableSnat: pulumi.Output<boolean | undefined>;
    /**
     * The Folder param. String can either be a specific string(`"Service Connections"`) or match this regex: `^[0-9a-zA-Z._\s-]{1,}$`. Default: `"Service Connections"`.
     */
    readonly folder: pulumi.Output<string>;
    /**
     * The Name param.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The PbfOnly param.
     */
    readonly pbfOnly: pulumi.Output<boolean | undefined>;
    /**
     * The Targets param.
     */
    readonly targets: pulumi.Output<string[]>;
    readonly tfid: pulumi.Output<string>;
    /**
     * Create a ServiceConnectionGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ServiceConnectionGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ServiceConnectionGroup resources.
 */
export interface ServiceConnectionGroupState {
    /**
     * The DisableSnat param.
     */
    disableSnat?: pulumi.Input<boolean>;
    /**
     * The Folder param. String can either be a specific string(`"Service Connections"`) or match this regex: `^[0-9a-zA-Z._\s-]{1,}$`. Default: `"Service Connections"`.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The PbfOnly param.
     */
    pbfOnly?: pulumi.Input<boolean>;
    /**
     * The Targets param.
     */
    targets?: pulumi.Input<pulumi.Input<string>[]>;
    tfid?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ServiceConnectionGroup resource.
 */
export interface ServiceConnectionGroupArgs {
    /**
     * The DisableSnat param.
     */
    disableSnat?: pulumi.Input<boolean>;
    /**
     * The Folder param. String can either be a specific string(`"Service Connections"`) or match this regex: `^[0-9a-zA-Z._\s-]{1,}$`. Default: `"Service Connections"`.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The PbfOnly param.
     */
    pbfOnly?: pulumi.Input<boolean>;
    /**
     * The Targets param.
     */
    targets: pulumi.Input<pulumi.Input<string>[]>;
}
