import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.WildfireAntiVirusProfile("example", {folder: "Shared"});
 * ```
 */
export declare class WildfireAntiVirusProfile extends pulumi.CustomResource {
    /**
     * Get an existing WildfireAntiVirusProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: WildfireAntiVirusProfileState, opts?: pulumi.CustomResourceOptions): WildfireAntiVirusProfile;
    /**
     * Returns true if the given object is an instance of WildfireAntiVirusProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is WildfireAntiVirusProfile;
    /**
     * The Description param.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The MlavExceptions param.
     */
    readonly mlavExceptions: pulumi.Output<outputs.WildfireAntiVirusProfileMlavException[] | undefined>;
    /**
     * The Name param. String validation regex: `^[a-zA-Z0-9._-]+$`.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The PacketCapture param.
     */
    readonly packetCapture: pulumi.Output<boolean | undefined>;
    /**
     * The Rules param.
     */
    readonly rules: pulumi.Output<outputs.WildfireAntiVirusProfileRule[] | undefined>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The ThreatExceptions param.
     */
    readonly threatExceptions: pulumi.Output<outputs.WildfireAntiVirusProfileThreatException[] | undefined>;
    /**
     * Create a WildfireAntiVirusProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: WildfireAntiVirusProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering WildfireAntiVirusProfile resources.
 */
export interface WildfireAntiVirusProfileState {
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The MlavExceptions param.
     */
    mlavExceptions?: pulumi.Input<pulumi.Input<inputs.WildfireAntiVirusProfileMlavException>[]>;
    /**
     * The Name param. String validation regex: `^[a-zA-Z0-9._-]+$`.
     */
    name?: pulumi.Input<string>;
    /**
     * The PacketCapture param.
     */
    packetCapture?: pulumi.Input<boolean>;
    /**
     * The Rules param.
     */
    rules?: pulumi.Input<pulumi.Input<inputs.WildfireAntiVirusProfileRule>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
    /**
     * The ThreatExceptions param.
     */
    threatExceptions?: pulumi.Input<pulumi.Input<inputs.WildfireAntiVirusProfileThreatException>[]>;
}
/**
 * The set of arguments for constructing a WildfireAntiVirusProfile resource.
 */
export interface WildfireAntiVirusProfileArgs {
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The MlavExceptions param.
     */
    mlavExceptions?: pulumi.Input<pulumi.Input<inputs.WildfireAntiVirusProfileMlavException>[]>;
    /**
     * The Name param. String validation regex: `^[a-zA-Z0-9._-]+$`.
     */
    name?: pulumi.Input<string>;
    /**
     * The PacketCapture param.
     */
    packetCapture?: pulumi.Input<boolean>;
    /**
     * The Rules param.
     */
    rules?: pulumi.Input<pulumi.Input<inputs.WildfireAntiVirusProfileRule>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The ThreatExceptions param.
     */
    threatExceptions?: pulumi.Input<pulumi.Input<inputs.WildfireAntiVirusProfileThreatException>[]>;
}
